﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel.Composition;

namespace OGSNET.Plugins.GameYarou
{
    using OGSNET.Plugin;

    /** \brief ゲームヤロウゲームプラグイン ベースクラス */
    class GameYarouBase : GamePluginBase
    {
        /** \brief プラグインを開始する処理 */
        protected override void StartPlugin()
        {
            this.CallPlugin("GameYarou", this.LoadTopPage);
        }

        /** \brief トップページを読み込む */
        private void LoadTopPage()
        {
            this.Notice(this.GameInfo.GameName + "のトップページを読み込んでいます。");
            this.Navigate(this.GameStartUrl, this.GameStart);
        }

        /** \brief ゲームを起動する */
        private void GameStart()
        {
            // アクションをクリア
            this.ClearAction();

            // ゲームを開始
            this.Document.InvokeScript("eval", new object [] { "GameStartControl.StartExecuteGame()" });
            this.EndPlugin(this.GameInfo.GameName + "のクライアントを起動します。");
        }

        /** \brief ゲームを開始するURL */
        protected string GameStartUrl
        {
            get;
            set;
        }
    }

    /** \brief ゲームヤロウ チャネリング用プラグイン ベースクラス */
    class GameYarouChannelingBase : GamePluginBase
    {
        /** \brief プラグインを開始する処理 */
        protected override void StartPlugin()
        {
            this.CallPlugin("GameYarou", this.LoadLoginPage);
        }

        /** \brief ログインページを読み込む */
        private void LoadLoginPage()
        {
            this.Notice("ログインページを読み込んでいます。");
            this.Navigate(this.LoginUrl, this.LoadTopPage, this.LoginAfterUrl);
        }

        /** \brief トップページを読み込む */
        private void LoadTopPage()
        {
            // アクションをクリア
            this.ClearAction();

            this.Notice(this.GameInfo.GameName + "のトップページを読み込んでいます。");
            this.Navigate(this.GameStartUrl, this.GameStart);
        }

        /** \brief ゲームを起動する */
        private void GameStart()
        {
            // アクションをクリア
            this.ClearAction();

            // ゲームを開始
            this.Document.InvokeScript("eval", new object[] { this.GameStartScript });
            this.EndPlugin(this.GameInfo.GameName + "のクライアントを起動します。");
        }

        /** \brief 最終的にゲームを開始するURL */
        protected string GameStartUrl
        {
            get;
            set;
        }

        /** \brief ゲームヤロウからネクソンへログイン用のURL */
        protected string LoginUrl
        {
            get;
            set;
        }

        /** \brief ゲームヤロウからネクソンへログイン後のURL */
        protected string LoginAfterUrl
        {
            get;
            set;
        }

        /** \brief ゲームを開始するスクリプト */
        protected string GameStartScript
        {
            get;
            set;
        }
    }

    /** \brief サドンアタックのプラグイン */
    [Export(typeof(IPlugin))]
    [Export(typeof(IGamePlugin))]
    [ExportMetadata("PluginId", "GameYarou.SuddenAttack")]
    class SuddenAttack : GameYarouChannelingBase
    {
        /** \brief プラグインの初期化処理 */
        public SuddenAttack()
        {
            this.PluginInfo =
                new PluginInfo("1.1", "サドンアタック (ゲームヤロウ) 起動プラグイン", "pine",
                    "サドンアタック (ゲームヤロウ) の起動プラグインです。");

            this.GameInfo =
                new GameInfo("ゲームヤロウ", "GameYarou", "サドンアタック", "http://suddenattack.gameyarou.jp/");

            this.LoginUrl = "http://sa.nexon.co.jp/channel/login.aspx";
            this.LoginAfterUrl = "http://suddenattack.gameyarou.jp/";
            this.GameStartUrl = "http://sa.nexon.co.jp/channel/top.aspx";
            this.GameStartScript = "LaunchGame_suddenattack()";
        }
    }

    /** \brief デカロンのプラグイン */
    [Export(typeof(IPlugin))]
    [Export(typeof(IGamePlugin))]
    [ExportMetadata("PluginId", "GameYarou.Dekaron")]
    class Dekaron : GameYarouChannelingBase
    {
        /** \brief プラグインの初期化処理 */
        public Dekaron()
        {
            this.PluginInfo =
                new PluginInfo("1.1", "デカロン (ゲームヤロウ) 起動プラグイン", "pine",
                    "デカロン (ゲームヤロウ) の起動プラグインです。");

            this.GameInfo =
                new GameInfo("ゲームヤロウ", "GameYarou", "デカロン", "http://dekaron.gameyarou.jp/");

            this.LoginUrl = "http://dekaron.nexon.co.jp/channel/login.aspx";
            this.LoginAfterUrl = "http://dekaron.gameyarou.jp/";
            this.GameStartUrl = "http://dekaron.nexon.co.jp/channel/top.aspx";
            this.GameStartScript = " LaunchGame_dekaron()";
        }
    }

    /** \brief 三国志豪傑伝のプラグイン */
    [Export(typeof(IPlugin))]
    [Export(typeof(IGamePlugin))]
    [ExportMetadata("PluginId", "GameYarou.Sangokushi")]
    class Sangokushi : GameYarouBase
    {
        /** \brief プラグインの初期化処理 */
        public Sangokushi()
        {
            this.PluginInfo =
                new PluginInfo(new Version(1), "三国志豪傑伝 (ゲームヤロウ) 起動プラグイン", "pine",
                    "三国志豪傑伝 (ゲームヤロウ) の起動プラグインです。");

            this.GameInfo =
                new GameInfo("ゲームヤロウ", "GameYarou", "三国志豪傑伝", "http://sangokushi-hero.gameyarou.jp/");

            this.GameStartUrl = "http://sangokushi-hero.gameyarou.jp/main/index.asp";
        }
    }

    /** \brief ノーステイルのプラグイン */
    [Export(typeof(IPlugin))]
    [Export(typeof(IGamePlugin))]
    [ExportMetadata("PluginId", "GameYarou.Nostale")]
    class Nostale : GameYarouBase
    {
        /** \brief プラグインの初期化処理 */
        public Nostale()
        {
            this.PluginInfo =
                new PluginInfo(new Version(1), "ノーステイル (ゲームヤロウ) 起動プラグイン", "pine",
                    "ノーステイル (ゲームヤロウ) の起動プラグインです。");

            this.GameInfo =
                new GameInfo("ゲームヤロウ", "GameYarou", "ノーステイル", "http://nostale.gameyarou.jp/");

            this.GameStartUrl = "http://nostale.gameyarou.jp/";
        }
    }

    /** \brief 鉄鬼のプラグイン */
    [Export(typeof(IPlugin))]
    [Export(typeof(IGamePlugin))]
    [ExportMetadata("PluginId", "GameYarou.Tekki")]
    class Tekki : GameYarouChannelingBase
    {
        /** \brief プラグインの初期化処理 */
        public Tekki()
        {
            this.PluginInfo =
                new PluginInfo("1.1", "鉄鬼 (ゲームヤロウ) 起動プラグイン", "pine",
                    "鉄鬼 (ゲームヤロウ) の起動プラグインです。");

            this.GameInfo =
                new GameInfo("ゲームヤロウ", "GameYarou", "鉄鬼", "http://tekki.gameyarou.jp/");


            this.LoginUrl = "http://tekki.nexon.co.jp/channel/login.aspx";
            this.LoginAfterUrl = "http://tekki.gameyarou.jp/";
            this.GameStartUrl = "http://tekki.nexon.co.jp/channel/top.aspx";
            this.GameStartScript = "LaunchGame_tekki()";
        }
    }
}
